@@ -5,7 +5,7 @@ use 5.6.2;
 use XML::LibXML '1.69';
 use Test::Builder;
 
-our $VERSION = '0.14';
+our $VERSION = '0.15';
 
 sub new {
     my ($class, %p) = @_;
@@ -24,7 +24,7 @@ sub new {
                 if (ref $f eq 'CODE') {
                     $f;
                 } elsif ($f eq 'css_selector') {
-                    eval 'require HTML::Selector::XPath';
+                    eval 'use HTML::Selector::XPath 0.06';
                     die 'Please install HTML::Selector::XPath to use CSS selectors'
                         if $@;
                     sub {
